@@ -8,9 +8,18 @@ export LANG='C.UTF-8'
 dpkg-checkbuilddeps -d 'python3-apt, apt-btrfs-snapshot, parsewiki, python3-feedparser,
 			python3-mock, xvfb, gir1.2-gtk-3.0, python3-gi, python3-nose, pep8, python3-distutils-extra, python3-update-manager'
 
+# run the test-suite
+# echo "Running integrated tests"
+xvfb-run nosetests3
+
+# test leftovers
+# echo "Cleaning up after tests"
+rm -f ./tests/data-sources-list-test/apt.log
+rm -f ./tests/data-sources-list-test/Ubuntu.mirrors
+
 # update demotions
 # echo "Running demotions"
-(cd utils && ./demotions.py bionic cosmic > demoted.cfg)
+(cd utils && ./demotions.py cosmic disco > demoted.cfg)
 # when this gets enabled, make sure to add symlink in DistUpgrade
 # echo "Running lts demotions"
 #(cd utils && ./demotions.py xenial bionic > demoted.cfg.xenial)
@@ -21,8 +30,24 @@ if [ ! -e /usr/lib/python3/dist-packages/apt_btrfs_snapshot.py ]; then
     echo "please sudo apt-get install apt-btrfs-snapshot"
     exit 1
 fi
+echo "copying apt_btrfs_snapshot.py for the upgrader tarball"
 cp /usr/lib/python3/dist-packages/apt_btrfs_snapshot.py DistUpgrade
 
+# update invoke-rc.d copy, requires init-system-helpers
+if [ ! -e /usr/sbin/invoke-rc.d ]; then
+    echo "please sudo apt install init-system-helpers"
+    exit 1
+fi
+if [ ! -e /usr/bin/patch ]; then
+    echo "please sudo apt install patch"
+    exit 1
+fi
+echo "copying invoke-rc.d for the upgrader tarball"
+cp /usr/sbin/invoke-rc.d DistUpgrade/imported/
+# now patch the file so the upgrade can continue even if there are errors
+patch --fuzz=0 -p0 DistUpgrade/imported/invoke-rc.d DistUpgrade/imported/invoke-rc.d.diff || { echo "patch didn't apply cleanly" && exit 1; }
+
+
 # (auto) generate the required html
 if [ ! -x /usr/bin/parsewiki ]; then
     echo "please sudo apt-get install parsewiki"
@@ -53,15 +78,6 @@ rm -rf utils/apt/lists utils/apt/*.bin
 # echo "Running update mirrors"
 (cd utils && ./update_mirrors.py ../data/mirrors.cfg)
 
-# run the test-suite
-# echo "Running integrated tests"
-xvfb-run nosetests3
-
-# test leftovers
-# echo "Cleaning up after tests"
-rm -f ./tests/data-sources-list-test/apt.log
-rm -f ./tests/data-sources-list-test/Ubuntu.mirrors
-
 # update version
 DEBVER=$(LC_ALL=C dpkg-parsechangelog |sed -n -e '/^Version:/s/^Version: //p' | sed s/.*://)
 echo "VERSION = '$DEBVER'" > DistUpgrade/DistUpgradeVersion.py
